@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "recursion-indicator" "1.1"
+(define-package "recursion-indicator" "20250921.1714"
   "Recursion indicator."
-  '((emacs  "27.1")
-    (compat "29.1.4.4"))
+  '((emacs  "29.1")
+    (compat "30"))
   :url "https://github.com/minad/recursion-indicator"
-  :commit "548838df2ef15fdd8e9d904d0a74182297e3383f"
-  :revdesc "548838df2ef1"
+  :commit "91140813d5f54f2ab56116914a10d1f7aae65826"
+  :revdesc "91140813d5f5"
   :keywords '("convenience")
   :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
   :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
